# SignUpCreatePaymentMethodPayPalAdaptive


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**preapproval_key** | **str** | The PayPal preapproval key.  | [optional] 

## Example

```python
from zuora_sdk.models.sign_up_create_payment_method_pay_pal_adaptive import SignUpCreatePaymentMethodPayPalAdaptive

# TODO update the JSON string below
json = "{}"
# create an instance of SignUpCreatePaymentMethodPayPalAdaptive from a JSON string
sign_up_create_payment_method_pay_pal_adaptive_instance = SignUpCreatePaymentMethodPayPalAdaptive.from_json(json)
# print the JSON string representation of the object
print(SignUpCreatePaymentMethodPayPalAdaptive.to_json())

# convert the object into a dict
sign_up_create_payment_method_pay_pal_adaptive_dict = sign_up_create_payment_method_pay_pal_adaptive_instance.to_dict()
# create an instance of SignUpCreatePaymentMethodPayPalAdaptive from a dict
sign_up_create_payment_method_pay_pal_adaptive_from_dict = SignUpCreatePaymentMethodPayPalAdaptive.from_dict(sign_up_create_payment_method_pay_pal_adaptive_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


